@@ -33,6 +33,9 @@
 /*	Google, Inc.
 /*	111 8th Avenue
 /*	New York, NY 10011, USA
+/*
+/*	Wietse Venema
+/*	porcupine.org
 /*--*/
 
 /* System library. */
@@ -137,7 +140,8 @@ CLEANUP_STATE *cleanup_state_alloc(VSTREAM *src)
     state->milter_err_text = 0;
     state->milter_dsn_buf = 0;
     state->free_regions = state->body_regions = state->curr_body_region = 0;
-    state->smtputf8 = 0;
+    state->sendopts = 0;
+    state->valid_reqtls_esmtp_hdr = 0;
     return (state);
 }
 
