@@ -798,15 +798,6 @@ static int qmgr_message_read(QMGR_MESSAGE *message)
 	myfree(orig_rcpt);
     }
 
-    /*
-     * If the sender requested REQUIRETLS, don't bounce full messages. This
-     * is better enforced here than in delivery agents and bounce service
-     * daemons.
-     */
-    if (var_requiretls_enable
-	&& (message->sendopts & SOPT_REQUIRETLS_ESMTP))
-	message->dsn_ret = DSN_RET_HDRS;
-
     /*
      * After sending a "delayed" warning, request sender notification when
      * message delivery is completed. While "mail delayed" notifications are
@@ -1142,7 +1133,7 @@ static void qmgr_message_resolve(QMGR_MESSAGE *message)
 		&& !var_double_bounce_sender[len]) {
 		status = sent(message->tflags, message->queue_id,
 			      QMGR_MSG_STATS(&stats, message), recipient,
-			      "none", DSN_SIMPLE(&dsn, "2.0.0",
+			      "none", NO_TLS_STATS, DSN_SIMPLE(&dsn, "2.0.0",
 			"undeliverable postmaster notification discarded"));
 		if (status == 0) {
 		    deliver_completed(message->fp, recipient->offset);
