@@ -36,8 +36,6 @@
 /*	Google, Inc.
 /*	111 8th Avenue
 /*	New York, NY 10011, USA
-/*
-/*	Wietse Venema
 /*--*/
 
 /* System library. */
@@ -95,8 +93,7 @@ static char *dict_random_parse_name(DICT *dict, ARGV **argv,
     VSTRING *b64 = 0;
     char   *err = 0;
 
-    while ((arg = mystrtokq_cw(&bp, delim, parens,
-			       DICT_TYPE_RANDOM ":{...}")) != 0) {
+    while ((arg = mystrtokq(&bp, delim, parens)) != 0) {
 	if (dict->flags & DICT_FLAG_SRC_RHS_IS_FILE) {
 	    if ((b64 = dict_file_to_b64(dict, arg)) != 0) {
 		argv_add(argvp, vstring_str(b64), (char *) 0);
@@ -178,5 +175,5 @@ DICT   *dict_random_open(const char *name, int open_flags, int dict_flags)
 					  "%s", err));
     }
     dict_file_purge_buffers(&dict_random->dict);
-    DICT_RANDOM_RETURN(DICT_DEBUG (&dict_random->dict));
+    DICT_RANDOM_RETURN(&dict_random->dict);
 }
